@@ -9,25 +9,27 @@ been reviewed for security issues. DON'T USE IT FOR PRODUCTION USE!
 
 from __future__ import unicode_literals
 
-import os
+from io import BytesIO
 import socket
 import sys
 import traceback
-try:
-    from urllib.parse import urljoin
-except ImportError:     # Python 2
-    from urlparse import urljoin
-from django.utils.six.moves import socketserver
 from wsgiref import simple_server
-from wsgiref.util import FileWrapper   # for backwards compatibility
+from wsgiref.util import FileWrapper   # NOQA: for backwards compatibility
 
-import django
 from django.core.exceptions import ImproperlyConfigured
 from django.core.management.color import color_style
 from django.core.wsgi import get_wsgi_application
-from django.utils.importlib import import_module
+from django.utils import six
+from django.utils.module_loading import import_string
+from django.utils.six.moves import socketserver
 
-__all__ = ['WSGIServer', 'WSGIRequestHandler']
+__all__ = ('WSGIServer', 'WSGIRequestHandler', 'MAX_SOCKET_CHUNK_SIZE')
+
+
+# If data is too large, socket will choke, so write chunks no larger than 32MB
+# at a time. The rationale behind the 32MB can be found on Django's Trac:
+# https://code.djangoproject.com/ticket/5596#comment:4
+MAX_SOCKET_CHUNK_SIZE = 32 * 1024 * 1024  # 32 MB
 
 
 def get_internal_wsgi_application():
@@ -49,22 +51,19 @@ def get_internal_wsgi_application():
     app_path = getattr(settings, 'WSGI_APPLICATION')
     if app_path is None:
         return get_wsgi_application()
-    module_name, attr = app_path.rsplit('.', 1)
-    try:
-        mod = import_module(module_name)
-    except ImportError as e:
-        raise ImproperlyConfigured(
-            "WSGI application '%s' could not be loaded; "
-            "could not import module '%s': %s" % (app_path, module_name, e))
-    try:
-        app = getattr(mod, attr)
-    except AttributeError as e:
-        raise ImproperlyConfigured(
-            "WSGI application '%s' could not be loaded; "
-            "can't find '%s' in module '%s': %s"
-            % (app_path, attr, module_name, e))
 
-    return app
+    try:
+        return import_string(app_path)
+    except ImportError as e:
+        msg = (
+            "WSGI application '%(app_path)s' could not be loaded; "
+            "Error importing module: '%(exception)s'" % ({
+                'app_path': app_path,
+                'exception': e,
+            })
+        )
+        six.reraise(ImproperlyConfigured, ImproperlyConfigured(msg),
+                    sys.exc_info()[2])
 
 
 class ServerHandler(simple_server.ServerHandler, object):
@@ -86,19 +85,9 @@ class ServerHandler(simple_server.ServerHandler, object):
             self.bytes_sent += len(data)
 
         # XXX check Content-Length and truncate if too many bytes written?
-
-        # If data is too large, socket will choke, so write chunks no larger
-        # than 32MB at a time.
-        length = len(data)
-        if length > 33554432:
-            offset = 0
-            while offset < length:
-                chunk_size = min(33554432, length)
-                self._write(data[offset:offset+chunk_size])
-                self._flush()
-                offset += chunk_size
-        else:
-            self._write(data)
+        data = BytesIO(data)
+        for chunk in iter(lambda: data.read(MAX_SOCKET_CHUNK_SIZE), b''):
+            self._write(chunk)
             self._flush()
 
     def error_output(self, environ, start_response):
@@ -120,6 +109,8 @@ class ServerHandler(simple_server.ServerHandler, object):
 class WSGIServer(simple_server.WSGIServer, object):
     """BaseHTTPServer that implements the Python WSGI protocol"""
 
+    request_queue_size = 10
+
     def __init__(self, *args, **kwargs):
         if kwargs.pop('ipv6', False):
             self.address_family = socket.AF_INET6
@@ -134,11 +125,6 @@ class WSGIServer(simple_server.WSGIServer, object):
 class WSGIRequestHandler(simple_server.WSGIRequestHandler, object):
 
     def __init__(self, *args, **kwargs):
-        from django.conf import settings
-        self.admin_static_prefix = urljoin(settings.STATIC_URL, 'admin/')
-        # We set self.path to avoid crashes in log_message() on unsupported
-        # requests (like "OPTIONS").
-        self.path = ''
         self.style = color_style()
         super(WSGIRequestHandler, self).__init__(*args, **kwargs)
 
@@ -147,11 +133,6 @@ class WSGIRequestHandler(simple_server.WSGIRequestHandler, object):
         return self.client_address[0]
 
     def log_message(self, format, *args):
-        # Don't bother logging requests for admin images or the favicon.
-        if (self.path.startswith(self.admin_static_prefix)
-                or self.path == '/favicon.ico'):
-            return
-
         msg = "[%s] %s\n" % (self.log_date_time_string(), format % args)
 
         # Utilize terminal colors, if available
